document.addEventListener("DOMContentLoaded", function () {
    // Data
    const data = [
        { brand: "Scion", horsepower: 156.6154, torque: 156, highway_mpg: 29.84615 },
        { brand: "MINI", horsepower: 160.9677, torque: 155.0323, highway_mpg: 33.87097 },
        { brand: "Kia", horsepower: 179.7407, torque: 170.6741, highway_mpg: 30.94815 },
        { brand: "Honda", horsepower: 188.225, torque: 175.27, highway_mpg: 30.41 },
        { brand: "Volkswagen", horsepower: 192.4961, torque: 210.4884, highway_mpg: 30.1938 },
        { brand: "Mitsubishi", horsepower: 195.3529, torque: 196.1961, highway_mpg: 26.68627 },
        { brand: "Subaru", horsepower: 205.2095, torque: 200.8667, highway_mpg: 26.53333 },
        { brand: "Saab", horsepower: 222.5424, torque: 236.1864, highway_mpg: 27.52542 },
        { brand: "Lotus", horsepower: 231, torque: 168.0909, highway_mpg: 26.36364 },
        { brand: "Volvo", horsepower: 247.2427, torque: 254.2039, highway_mpg: 25.71845 },
        { brand: "Toyota", horsepower: 253.4492, torque: 257.1446, highway_mpg: 23.93846 },
        { brand: "Acura", horsepower: 262.8485, torque: 239.2727, highway_mpg: 25.84848 },
        { brand: "Mercedes", horsepower: 280.2188, torque: 298.875, highway_mpg: 23.15625 },
        { brand: "Audi", horsepower: 300.1839, torque: 297.908, highway_mpg: 25.17241 },
        { brand: "Lexus", horsepower: 301.6154, torque: 278.9231, highway_mpg: 25.25 },
        { brand: "Infiniti", horsepower: 322.1294, torque: 281.4235, highway_mpg: 24.29412 },
        { brand: "Cadillac", horsepower: 340.98, torque: 324.76, highway_mpg: 22.52 },
        { brand: "BMW", horsepower: 347.1805, torque: 349.5338, highway_mpg: 24.32331 },
        { brand: "Land Rover", horsepower: 373.8571, torque: 363.2857, highway_mpg: 19.54286 },
        { brand: "Porsche", horsepower: 376.549, torque: 330.0588, highway_mpg: 24 },
        { brand: "Mercedes-Benz", horsepower: 388.4286, torque: 421.1429, highway_mpg: 20.42857 },
        { brand: "Maserati", horsepower: 422.5, torque: 353.6667, highway_mpg: 19.41667 },
        { brand: "Jaguar", horsepower: 448.75, torque: 418.7955, highway_mpg: 22.18182 },
        { brand: "Aston Martin", horsepower: 470, torque: 413.6512, highway_mpg: 18.44186 },
        { brand: "Rolls-Royce", horsepower: 475, torque: 539.8, highway_mpg: 18.4 },
        { brand: "Mercedes-AMG", horsepower: 494.8333, torque: 512.6667, highway_mpg: 16.83333 },
        { brand: "AMG", horsepower: 525.9, torque: 527.7, highway_mpg: 18.9 },
        { brand: "Ferrari", horsepower: 540, torque: 434, highway_mpg: 16 },
        { brand: "Lamborghini", horsepower: 554.8, torque: 398, highway_mpg: 20 },
        { brand: "Bentley", horsepower: 577.4444, torque: 576.3333, highway_mpg: 16.22222 },
        { brand: "Maybach", horsepower: 599.8462, torque: 720.9231, highway_mpg: 16 }
    ];

    // Dimensions
    const margin = { top: 20, right: 30, bottom: 30, left: 40 };
    const width = 800 - margin.left - margin.right;
    const height = 400 - margin.top - margin.bottom;

    // SVG Canvas
    const svg = d3.select("#chart")
        .append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom)
        .append("g")
        .attr("transform", `translate(${margin.left},${margin.top})`);

    // Scales
    const xScale = d3.scaleBand()
        .domain(data.map(d => d.brand))
        .range([0, width])
        .padding(0.1);

    const yScale = d3.scaleLinear()
        .domain([0, d3.max(data, d => d.horsepower)])
        .range([height, 0]);

    // Axes
    const xAxis = d3.axisBottom(xScale);
    const yAxis = d3.axisLeft(yScale);

    // Draw Axes
    svg.append("g")
        .attr("class", "x-axis")
        .attr("transform", `translate(0, ${height})`)
        .call(xAxis);

    svg.append("g")
        .attr("class", "y-axis")
        .call(yAxis);

    // Bars
    const bars = svg.selectAll(".bar")
        .data(data)
        .enter()
        .append("rect")
        .attr("class", "bar")
        .attr("x", d => xScale(d.brand))
        .attr("y", d => yScale(d.horsepower))
        .attr("width", xScale.bandwidth())
        .attr("height", d => height - yScale(d.horsepower))
        .style("fill", "steelblue");
});
